summaryrefslogtreecommitdiff
path: root/sys/kern/uipc_socket2.c
diff options
context:
space:
mode:
authorPhilip Guenther <guenther@cvs.openbsd.org>2022-02-25 23:51:05 +0000
committerPhilip Guenther <guenther@cvs.openbsd.org>2022-02-25 23:51:05 +0000
commit35d935e7af10bc634f79c37722158ba200732393 (patch)
tree204598a1369d152503cd594dbe6d3ad5b7dd1630 /sys/kern/uipc_socket2.c
parent4f8344a22bf26c93d3595f04fc892a8bb47e268a (diff)
Reported-by: syzbot+1b5b209ce506db4d411d@syzkaller.appspotmail.com
Revert the pr_usrreqs move: syzkaller found a NULL pointer deref and I won't be available to monitor for followup issues for a bit
Diffstat (limited to 'sys/kern/uipc_socket2.c')
-rw-r--r--sys/kern/uipc_socket2.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/sys/kern/uipc_socket2.c b/sys/kern/uipc_socket2.c
index df506fd5ada..befc826548d 100644
--- a/sys/kern/uipc_socket2.c
+++ b/sys/kern/uipc_socket2.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: uipc_socket2.c,v 1.119 2022/02/25 08:36:01 guenther Exp $ */
+/* $OpenBSD: uipc_socket2.c,v 1.120 2022/02/25 23:51:03 guenther Exp $ */
/* $NetBSD: uipc_socket2.c,v 1.11 1996/02/04 02:17:55 christos Exp $ */
/*
@@ -150,7 +150,7 @@ sonewconn(struct socket *head, int connstatus)
/*
* XXXSMP as long as `so' and `head' share the same lock, we
* can call soreserve() and pru_attach() below w/o explicitly
* locking `so'.
*/
soassertlocked(head);
@@ -194,7 +194,7 @@ sonewconn(struct socket *head, int connstatus)
sigio_copy(&so->so_sigio, &head->so_sigio);
soqinsque(head, so, soqueue);
- if ((*so->so_proto->pr_usrreqs->pru_attach)(so, 0)) {
+ if ((*so->so_proto->pr_attach)(so, 0)) {
(void) soqremque(so, soqueue);
sigio_free(&so->so_sigio);
klist_free(&so->so_rcv.sb_sel.si_note);
@@ -150,7 +150,7 @@ sonewconn(struct socket *head, int connstatus)
/*
* XXXSMP as long as `so' and `head' share the same lock, we
- * can call soreserve() and pru_attach() below w/o explicitly
+ * can call soreserve() and pr_attach() below w/o explicitly
* locking `so'.
*/